-- shared_buffers = 1024MB
-- work_mem = 100MB

show shared_buffers;
show work_mem;

drop table if exists aaa;
create table aaa as select floor(random()*50)::int num, (random()*10 < 1)::int flag from generate_series(1, 10000000) id;
create index i1 on aaa  (num);
create index i2 on aaa  (flag);
analyze aaa;

select relname, reltuples::bigint, relpages::bigint, (reltuples/relpages)::bigint tpp from pg_class where relname in('aaa','i1','i2') order by relname;

select * from pg_stats where tablename='aaa';

SELECT 
  *
FROM (
  SELECT 
    relname AS "table",
    reltuples::BIGINT AS "~count",
    pg_size_pretty(pg_relation_size(C.oid)) AS "size",
    pg_size_pretty(pg_table_size(C.oid) - pg_relation_size(C.oid)) AS "toast",
    pg_size_pretty(pg_indexes_size(C.oid)) AS "idx",
    pg_size_pretty(pg_total_relation_size(C.oid)) AS "size + toast + idx"
  FROM 
    pg_class C
  LEFT JOIN 
    pg_namespace N ON (N.oid = C.relnamespace)
  WHERE 
    N.nspname = 'public' and C.relkind = 'r' and relname='aaa'
)_ 
ORDER BY 
  "~count" DESC;

SELECT 
  ST.relname AS "table", 
  ST.indexrelname AS "index",  
  pg_size_pretty(pg_relation_size(ST.indexrelid)) AS "idx_size", 
  ST.idx_scan AS "idx_scan",
  IDX.indisunique AS "is_unique",
  ARRAY(
    SELECT 
      pg_get_indexdef(IDX.indexrelid, k + 1, true)
    FROM 
      generate_subscripts(IDX.indkey, 1) AS k
    ORDER BY k
  ) AS "indkey_names"
FROM 
  pg_stat_user_indexes ST
LEFT JOIN 
  pg_index IDX ON IDX.indexrelid = ST.indexrelid
WHERE 
  ST.relname='aaa'
ORDER BY 
  pg_relation_size(ST.indexrelid) DESC, ST.indexrelname;
